# dbtunnel 

Proxy solution to run elegant Web UIs natively inside databricks notebooks.

## Description

Easy way to test the following things on a databricks cluster and notebooks

* [x] fastapi
* [x] gradio
* [x] stable diffusion webui
* [x] streamlit
* [x] nicegui
* [x] flask
* [x] dash
* [x] bokeh


## Disclaimer
dbtunnel is not developed, endorsed not supported by Databricks. It is provided as-is; no warranty is derived from using this package. For more details, please refer to the license.